Enumeration
MalcontentWebFilterType
unstable since: 0.14.0
Description [src]
Types of web filtering which can be imposed on an account.
Additional types may be added in future.
Available since: 0.14.0
Members
-
MCT_WEB_FILTER_TYPE_NONE -
The user’s web access is not filtered.
- Value:
0 - Available since: 0.14.0
- Value:
-
MCT_WEB_FILTER_TYPE_BLOCKLIST -
Websites are allowed by default unless they’re listed in one of the block lists or the custom block list. The allow lists and custom allow list override the block lists.
- Value:
1 - Available since: 0.14.0
- Value:
-
MCT_WEB_FILTER_TYPE_ALLOWLIST -
Websites are blocked by default unless they’re listed in one of the allow lists or the custom allow list. The block lists are ignored.
- Value:
2 - Available since: 0.14.0
- Value: